================
Acknowledgements
================

The PALEOMIX pipeline has been developed by researchers at the `Orlando Group`_ at the `Centre for GeoGenetics`_, University of Copenhagen, Denmark. Its development was supported by the Danish Council for Independent Research, Natural Sciences (FNU); the Danish National Research Foundation (DNRF94); a Marie-Curie Career Integration grant (FP7 CIG-293845); the Lundbeck foundation (R52-A5062).

.. _Orlando Group: http://geogenetics.ku.dk/research_groups/palaeomix_group/
.. _Centre for GeoGenetics: http://geogenetics.ku.dk/